@@ -10,7 +10,7 @@ import { RegistryItem } from '../utils';
 import { Registry } from '../utils/Registry';
 
 import { getScaleCalculator, ColorScaleValue } from './scale';
-import { fallBackTreshold } from './thresholds';
+import { fallBackThreshold } from './thresholds';
 
 /** @beta */
 export type FieldValueColorCalculator = (value: number, percent: number, Threshold?: Threshold) => string;
@@ -46,7 +46,7 @@ export const fieldColorModeRegistry = new Registry<FieldColorMode>(() => {
       description: 'Derive colors from thresholds',
       getCalculator: (_field, theme) => {
         return (_value, _percent, threshold) => {
-          const thresholdSafe = threshold ?? fallBackTreshold;
+          const thresholdSafe = threshold ?? fallBackThreshold;
           return theme.visualization.getColorByName(thresholdSafe.color);
         };
       },
@@ -251,7 +251,7 @@ export function getFieldSeriesColor(field: Field, theme: GrafanaTheme2): ColorSc
   if (!mode.isByValue) {
     return {
       color: mode.getCalculator(field, theme)(0, 0),
-      threshold: fallBackTreshold,
+      threshold: fallBackThreshold,
       percent: 1,
     };
   }
