@@ -19,10 +19,14 @@ export interface StandardEditorContext<TOptions, TState = any> {
 export interface StandardEditorProps<TValue = any, TSettings = any, TOptions = any, TState = any> {
   value: TValue;
   onChange: (value?: TValue) => void;
-  item: StandardEditorsRegistryItem<TValue, TSettings>;
   context: StandardEditorContext<TOptions, TState>;
   id?: string;
+
+  item: RegistryItem & {
+    settings?: TSettings;
+  };
 }
+
 export interface StandardEditorsRegistryItem<TValue = any, TSettings = any> extends RegistryItem {
   editor: ComponentType<StandardEditorProps<TValue, TSettings>>;
   settings?: TSettings;
