@@ -9,6 +9,7 @@ import { filterByValueTransformer } from './transformers/filterByValue';
 import { formatStringTransformer } from './transformers/formatString';
 import { formatTimeTransformer } from './transformers/formatTime';
 import { groupByTransformer } from './transformers/groupBy';
+import { groupToNestedTable } from './transformers/groupToNestedTable';
 import { groupingToMatrixTransformer } from './transformers/groupingToMatrix';
 import { histogramTransformer } from './transformers/histogram';
 import { joinByFieldTransformer } from './transformers/joinByField';
@@ -53,4 +54,5 @@ export const standardTransformers = {
   convertFieldTypeTransformer,
   groupingToMatrixTransformer,
   limitTransformer,
+  groupToNestedTable,
 };
