@@ -92,14 +92,16 @@ export const filterByValueTransformer: DataTransformerInfo<FilterByValueTransfor
 
     return source.pipe(
       map((data) => {
-        if (!Array.isArray(data) || data.length === 0) {
+        if (data.length === 0) {
           return data;
         }
 
-        const rows = new Set<number>();
+        const processed: DataFrame[] = [];
+
+        const fieldIndexByName = groupFieldIndexByName(data);
 
         for (const frame of data) {
-          const fieldIndexByName = groupFieldIndexByName(frame, data);
+          const rows = new Set<number>();
 
           let matchers;
           if (transformationsVariableSupport()) {
@@ -135,13 +137,9 @@ export const filterByValueTransformer: DataTransformerInfo<FilterByValueTransfor
               rows.add(index);
             }
           }
-        }
 
-        const processed: DataFrame[] = [];
-        const frameLength = include ? rows.size : data[0].length - rows.size;
-
-        for (const frame of data) {
           const fields: Field[] = [];
+          const frameLength = include ? rows.size : data[0].length - rows.size;
 
           for (const field of frame.fields) {
             const buffer = [];
@@ -198,10 +196,15 @@ const createFilterValueMatchers = (
   });
 };
 
-const groupFieldIndexByName = (frame: DataFrame, data: DataFrame[]): Record<string, number> => {
-  return frame.fields.reduce((all: Record<string, number>, field, fieldIndex) => {
-    const fieldName = getFieldDisplayName(field, frame, data);
-    all[fieldName] = fieldIndex;
-    return all;
-  }, {});
+const groupFieldIndexByName = (data: DataFrame[]) => {
+  const lookup: Record<string, number> = {};
+
+  for (const frame of data) {
+    frame.fields.forEach((field, fieldIndex) => {
+      const fieldName = getFieldDisplayName(field, frame, data);
+      lookup[fieldName] = fieldIndex;
+    });
+  }
+
+  return lookup;
 };
