@@ -39,4 +39,6 @@ export enum DataTransformerID {
   timeSeriesTable = 'timeSeriesTable',
   formatTime = 'formatTime',
   formatString = 'formatString',
+  regression = 'regression',
+  groupToNestedTable = 'groupToNestedTable',
 }
