@@ -21,7 +21,7 @@ const seriesAWithMultipleFields = toDataFrame({
   name: 'A',
   fields: [
     { name: 'time', type: FieldType.time, values: [3000, 4000, 5000, 6000] },
-    { name: 'temperature', type: FieldType.number, values: [3, 4, 5, 6] },
+    { name: 'temperature', type: FieldType.number, values: [3, 4, 5, 6, 6] },
     { name: 'humidity', type: FieldType.number, values: [10000.3, 10000.4, 10000.5, 10000.6] },
   ],
 });
@@ -52,7 +52,14 @@ describe('Reducer Transformer', () => {
     const cfg = {
       id: DataTransformerID.reduce,
       options: {
-        reducers: [ReducerID.first, ReducerID.min, ReducerID.max, ReducerID.last],
+        reducers: [
+          ReducerID.first,
+          ReducerID.min,
+          ReducerID.max,
+          ReducerID.last,
+          ReducerID.uniqueValues,
+          ReducerID.count,
+        ],
       },
     };
 
@@ -90,6 +97,25 @@ describe('Reducer Transformer', () => {
             values: [6, 10000.6, 7, 11000.7],
             config: {},
           },
+          {
+            // expect type other
+            name: 'All unique values',
+            type: FieldType.other,
+            values: [
+              [3, 4, 5, 6],
+              [10000.3, 10000.4, 10000.5, 10000.6],
+              [1, 3, 5, 7],
+              [11000.1, 11000.3, 11000.5, 11000.7],
+            ],
+            config: {},
+          },
+          {
+            // expect type number
+            name: 'Count',
+            type: FieldType.number,
+            values: [5, 4, 4, 4],
+            config: {},
+          },
         ];
 
         expect(processed.length).toEqual(1);
