@@ -58,9 +58,7 @@ export interface ExploreLogsPanelState {
 
 export interface SplitOpenOptions<T extends AnyQuery = AnyQuery> {
   datasourceUid: string;
-  /** @deprecated Will be removed in a future version. Use queries instead. */
-  query?: T;
-  queries?: T[];
+  queries: T[];
   range?: TimeRange;
   panelsState?: ExplorePanelsState;
   correlationHelperData?: ExploreCorrelationHelperData;
