@@ -85,10 +85,12 @@ export const availableIconsIndex = {
   'dice-three': true,
   docker: true,
   'document-info': true,
+  'document-layout-left': true,
   'download-alt': true,
   draggabledots: true,
   edit: true,
   'ellipsis-v': true,
+  enter: true,
   envelope: true,
   'exchange-alt': true,
   'exclamation-triangle': true,
@@ -176,6 +178,7 @@ export const availableIconsIndex = {
   monitor: true,
   palette: true,
   'panel-add': true,
+  paragraph: true,
   'pathfinder-unite': true,
   pause: true,
   pen: true,
@@ -217,6 +220,8 @@ export const availableIconsIndex = {
   sync: true,
   'sync-slash': true,
   table: true,
+  'table-collapse-all': true,
+  'table-expand-all': true,
   'tag-alt': true,
   'telegram-alt': true,
   'text-fields': true,
