@@ -27,7 +27,7 @@ function renderUrl(path: string, query: UrlQueryMap | undefined): string {
   return path;
 }
 
-function encodeURIComponentAsAngularJS(val: string, pctEncodeSpaces?: boolean) {
+function encodeURIComponentAsAngularJS(val: EncodeURIComponentParams, pctEncodeSpaces?: boolean) {
   return encodeURIComponent(val)
     .replace(/%40/gi, '@')
     .replace(/%3A/gi, ':')
@@ -40,21 +40,31 @@ function encodeURIComponentAsAngularJS(val: string, pctEncodeSpaces?: boolean) {
     });
 }
 
-function toUrlParams(a: any) {
+type EncodeURIComponentParams = Parameters<typeof encodeURIComponent>[0];
+/**
+ *  Encodes URL parameters in the style of AngularJS.
+ *  Use `serializeParams` to encode parameters using `encodeURIComponent` instead.
+ */
+function toUrlParams(a: any, encodeAsAngularJS = true) {
   const s: any[] = [];
   const rbracket = /\[\]$/;
 
-  const isArray = (obj: any) => {
+  const encodingFunction = encodeAsAngularJS
+    ? (value: EncodeURIComponentParams, pctEncodeSpaces?: boolean) =>
+        encodeURIComponentAsAngularJS(value, pctEncodeSpaces)
+    : (value: EncodeURIComponentParams, _: boolean) => encodeURIComponent(value);
+
+  const isArray = (obj: unknown) => {
     return Object.prototype.toString.call(obj) === '[object Array]';
   };
 
   const add = (k: string, v: any) => {
     v = typeof v === 'function' ? v() : v === null ? '' : v === undefined ? '' : v;
     if (typeof v !== 'boolean') {
-      s[s.length] = encodeURIComponentAsAngularJS(k, true) + '=' + encodeURIComponentAsAngularJS(v, true);
+      s[s.length] = encodingFunction(k, true) + '=' + encodingFunction(v, true);
     } else {
-      const valueQueryPart = v ? '' : '=' + encodeURIComponentAsAngularJS('false', true);
-      s[s.length] = encodeURIComponentAsAngularJS(k, true) + valueQueryPart;
+      const valueQueryPart = v ? '' : '=' + encodingFunction('false', true);
+      s[s.length] = encodingFunction(k, true) + valueQueryPart;
     }
   };
 
@@ -92,6 +102,16 @@ function toUrlParams(a: any) {
   return buildParams('', a).join('&');
 }
 
+/**
+ * Converts params into a URL-encoded query string.
+ *
+ * @param params data to serialize
+ * @returns A URL-encoded string representing the provided data.
+ */
+function serializeParams(params: unknown): string {
+  return toUrlParams(params, false);
+}
+
 function appendQueryToUrl(url: string, stringToAppend: string) {
   if (stringToAppend !== undefined && stringToAppend !== null && stringToAppend !== '') {
     const pos = url.indexOf('?');
@@ -198,6 +218,7 @@ export const urlUtil = {
   appendQueryToUrl,
   getUrlSearchParams,
   parseKeyValue,
+  serializeParams,
 };
 
 /**
