@@ -22,9 +22,10 @@ import React, { useEffect, useState } from 'react';
 import { Icon } from '@grafana/ui';
 
 import { PIXELS_PER_LEVEL } from '../constants';
-import { ClickedItemData, ColorScheme, ColorSchemeDiff, TextAlign } from '../types';
+import { ClickedItemData, ColorScheme, ColorSchemeDiff, SelectedView, TextAlign } from '../types';
 
 import FlameGraphCanvas from './FlameGraphCanvas';
+import { GetExtraContextMenuButtonsFunction } from './FlameGraphContextMenu';
 import FlameGraphMetadata from './FlameGraphMetadata';
 import { CollapsedMap, FlameGraphDataContainer, LevelItem } from './dataTransform';
 
@@ -45,7 +46,10 @@ type Props = {
   onSandwichPillClick: () => void;
   colorScheme: ColorScheme | ColorSchemeDiff;
   showFlameGraphOnly?: boolean;
+  getExtraContextMenuButtons?: GetExtraContextMenuButtonsFunction;
   collapsing?: boolean;
+  selectedView: SelectedView;
+  search: string;
 };
 
 const FlameGraph = ({
@@ -64,7 +68,10 @@ const FlameGraph = ({
   onSandwichPillClick,
   colorScheme,
   showFlameGraphOnly,
+  getExtraContextMenuButtons,
   collapsing,
+  selectedView,
+  search,
 }: Props) => {
   const styles = getStyles();
 
@@ -122,7 +129,10 @@ const FlameGraph = ({
     showFlameGraphOnly,
     collapsedMap,
     setCollapsedMap,
+    getExtraContextMenuButtons,
     collapsing,
+    search,
+    selectedView,
   };
   const canvas = levelsCallers ? (
     <>
