@@ -2,8 +2,9 @@ import CopyWebpackPlugin from 'copy-webpack-plugin';
 import ESLintPlugin from 'eslint-webpack-plugin';
 import ForkTsCheckerWebpackPlugin from 'fork-ts-checker-webpack-plugin';
 import path from 'path';
+// @ts-expect-error - there are no types for this package
 import ReplaceInFileWebpackPlugin from 'replace-in-file-webpack-plugin';
-import { Configuration, DefinePlugin } from 'webpack';
+import { Configuration } from 'webpack';
 
 import { DIST_DIR } from './constants';
 import { getPackageJson, getPluginJson, getEntries, hasLicense } from './utils';
@@ -32,7 +33,7 @@ const config = async (env: Record<string, unknown>): Promise<Configuration> => {
       buildDependencies: {
         config: [__filename],
       },
-      cacheDirectory: path.resolve(__dirname, '../../.yarn/.cache/webpack', path.basename(process.cwd())),
+      cacheDirectory: path.resolve(__dirname, '../../node_modules/.cache/webpack', path.basename(process.cwd())),
     },
 
     context: process.cwd(),
@@ -144,6 +145,7 @@ const config = async (env: Record<string, unknown>): Promise<Configuration> => {
       },
       path: path.resolve(process.cwd(), DIST_DIR),
       publicPath: `public/plugins/${pluginJson.id}/`,
+      uniqueName: pluginJson.id,
     },
 
     plugins: [
@@ -184,27 +186,27 @@ const config = async (env: Record<string, unknown>): Promise<Configuration> => {
           ],
         },
       ]),
-      env.development
-        ? new ForkTsCheckerWebpackPlugin({
-            async: true,
-            issue: {
-              include: [{ file: '**/*.{ts,tsx}' }],
-            },
-            typescript: { configFile: path.join(process.cwd(), 'tsconfig.json') },
-          })
-        : new DefinePlugin({}),
-      env.development
-        ? new ESLintPlugin({
-            extensions: ['.ts', '.tsx'],
-            lintDirtyModulesOnly: true, // don't lint on start, only lint changed files
-            cacheLocation: path.resolve(
-              __dirname,
-              '../../.yarn/.cache/eslint-webpack-plugin',
-              path.basename(process.cwd()),
-              '.eslintcache'
-            ),
-          })
-        : new DefinePlugin({}),
+      ...(env.development
+        ? [
+            new ForkTsCheckerWebpackPlugin({
+              async: true,
+              issue: {
+                include: [{ file: '**/*.{ts,tsx}' }],
+              },
+              typescript: { configFile: path.join(process.cwd(), 'tsconfig.json') },
+            }),
+            new ESLintPlugin({
+              extensions: ['.ts', '.tsx'],
+              lintDirtyModulesOnly: true, // don't lint on start, only lint changed files
+              cacheLocation: path.resolve(
+                __dirname,
+                '../../node_modules/.cache/eslint-webpack-plugin',
+                path.basename(process.cwd()),
+                '.eslintcache'
+              ),
+            }),
+          ]
+        : []),
     ],
 
     resolve: {
@@ -212,6 +214,8 @@ const config = async (env: Record<string, unknown>): Promise<Configuration> => {
       unsafeCache: true,
     },
 
+    stats: 'minimal',
+
     watchOptions: {
       ignored: ['**/node_modules', '**/dist', '**/.yarn'],
     },
