@@ -539,7 +539,7 @@ describe('PrometheusDatasource', () => {
   });
 
   describe('interpolateVariablesInQueries', () => {
-    it('should call replace function 3 times', () => {
+    it('should call replace function 2 times', () => {
       const query: PromQuery = {
         expr: 'test{job="testjob"}',
         format: 'time_series',
@@ -550,7 +550,7 @@ describe('PrometheusDatasource', () => {
       replaceMock.mockReturnValue(interval);
 
       const queries = ds.interpolateVariablesInQueries([query], { Interval: { text: interval, value: interval } });
-      expect(templateSrvStub.replace).toBeCalledTimes(3);
+      expect(templateSrvStub.replace).toBeCalledTimes(2);
       expect(queries[0].interval).toBe(interval);
     });
 
@@ -682,26 +682,6 @@ describe('PrometheusDatasource', () => {
       const result = ds.applyTemplateVariables(query, {}, filters);
       expect(result).toMatchObject({ expr: 'test{job="99", k1="v1", k2!="v2"} > 99' });
     });
-
-    it('should replace variables in ad-hoc filters', () => {
-      const searchPattern = /\$A/g;
-      replaceMock.mockImplementation((a: string) => a?.replace(searchPattern, '99') ?? a);
-
-      const query = {
-        expr: 'test',
-        refId: 'A',
-      };
-      const filters = [
-        {
-          key: 'job',
-          operator: '=~',
-          value: '$A',
-        },
-      ];
-
-      const result = ds.applyTemplateVariables(query, {}, filters);
-      expect(result).toMatchObject({ expr: 'test{job=~"99"}' });
-    });
   });
 
   describe('metricFindQuery', () => {
