@@ -30,6 +30,7 @@ import {
 import {
   BackendDataSourceResponse,
   BackendSrvRequest,
+  config,
   DataSourceWithBackend,
   FetchResponse,
   getBackendSrv,
@@ -363,6 +364,11 @@ export class PrometheusDatasource
       // We need to pass utcOffsetSec to backend to calculate aligned range
       utcOffsetSec: request.range.to.utcOffset() * 60,
     };
+
+    if (config.featureToggles.promQLScope) {
+      processedTarget.scope = request.scope;
+    }
+
     if (target.instant && target.range) {
       // We have query type "Both" selected
       // We should send separate queries with different refId
@@ -722,11 +728,7 @@ export class PrometheusDatasource
     if (queries && queries.length) {
       expandedQueries = queries.map((query) => {
         const interpolatedQuery = this.templateSrv.replace(query.expr, scopedVars, this.interpolateQueryExpr);
-        const withAdhocFilters = this.templateSrv.replace(
-          this.enhanceExprWithAdHocFilters(filters, interpolatedQuery),
-          scopedVars,
-          this.interpolateQueryExpr
-        );
+        const withAdhocFilters = this.enhanceExprWithAdHocFilters(filters, interpolatedQuery);
 
         const expandedQuery = {
           ...query,
@@ -892,17 +894,11 @@ export class PrometheusDatasource
       value: '$__interval_ms',
     };
 
-    // We need a first replace to evaluate variables before applying adhoc filters
-    // This is required for an expression like `metric > $VAR` where $VAR is a float to which we must not add adhoc filters
+    // interpolate expression
     const expr = this.templateSrv.replace(target.expr, variables, this.interpolateQueryExpr);
 
-    // Apply ad-hoc filters
-    // When ad-hoc filters are applied, we replace again the variables in case the ad-hoc filters also reference a variable
-    const exprWithAdHocFilters = this.templateSrv.replace(
-      this.enhanceExprWithAdHocFilters(filters, expr),
-      variables,
-      this.interpolateQueryExpr
-    );
+    // Add ad hoc filters
+    const exprWithAdHocFilters = this.enhanceExprWithAdHocFilters(filters, expr);
 
     return {
       ...target,
