@@ -6,13 +6,7 @@
 export * from './services';
 export * from './config';
 export * from './analytics/types';
-export {
-  loadPluginCss,
-  SystemJS,
-  type PluginCssOptions,
-  setPluginImportUtils,
-  getPluginImportUtils,
-} from './utils/plugin';
+export { loadPluginCss, type PluginCssOptions, setPluginImportUtils, getPluginImportUtils } from './utils/plugin';
 export { reportMetaAnalytics, reportInteraction, reportPageview, reportExperimentView } from './analytics/utils';
 export { featureEnabled } from './utils/licensing';
 export { logInfo, logDebug, logWarning, logError, createMonitoringLogger } from './utils/logging';
@@ -23,6 +17,7 @@ export {
   type HealthCheckResultDetails,
   HealthStatus,
   type StreamOptionsProvider,
+  isExpressionReference,
 } from './utils/DataSourceWithBackend';
 export {
   toDataQueryResponse,
