@@ -11,6 +11,7 @@ import {
   createDataFrame,
   AdHocVariableFilter,
   ScopedVars,
+  getDefaultTimeRange,
 } from '@grafana/data';
 
 import { config } from '../config';
@@ -61,6 +62,15 @@ jest.mock('../services', () => ({
 jest.mock('./publicDashboardQueryHandler');
 
 describe('DataSourceWithBackend', () => {
+  beforeEach(async () => {
+    jest.useFakeTimers();
+    jest.setSystemTime(new Date('2023-10-13'));
+  });
+
+  afterEach(() => {
+    jest.useRealTimers();
+  });
+
   test('check the executed queries', () => {
     const { mock, ds } = createMockDatasource();
     ds.query({
@@ -70,6 +80,7 @@ describe('DataSourceWithBackend', () => {
       dashboardUID: 'dashA',
       panelId: 123,
       filters: [{ key: 'key1', operator: '=', value: 'val1' }],
+      range: getDefaultTimeRange(),
       queryGroupId: 'abc',
     } as DataQueryRequest);
 
@@ -79,6 +90,7 @@ describe('DataSourceWithBackend', () => {
     expect(args).toMatchInlineSnapshot(`
       {
         "data": {
+          "from": "1697133600000",
           "queries": [
             {
               "applyTemplateVariablesCalled": true,
@@ -111,6 +123,7 @@ describe('DataSourceWithBackend', () => {
               "refId": "B",
             },
           ],
+          "to": "1697155200000",
         },
         "headers": {
           "X-Dashboard-Uid": "dashA",
@@ -135,6 +148,7 @@ describe('DataSourceWithBackend', () => {
       targets: [{ refId: 'A' }, { refId: 'B', datasource: { type: '__expr__' } }],
       dashboardUID: 'dashA',
       panelId: 123,
+      range: getDefaultTimeRange(),
       queryGroupId: 'abc',
     } as DataQueryRequest);
 
@@ -144,6 +158,7 @@ describe('DataSourceWithBackend', () => {
     expect(args).toMatchInlineSnapshot(`
       {
         "data": {
+          "from": "1697133600000",
           "queries": [
             {
               "applyTemplateVariablesCalled": true,
@@ -167,6 +182,7 @@ describe('DataSourceWithBackend', () => {
               "refId": "B",
             },
           ],
+          "to": "1697155200000",
         },
         "headers": {
           "X-Dashboard-Uid": "dashA",
@@ -190,6 +206,7 @@ describe('DataSourceWithBackend', () => {
     ds.query({
       maxDataPoints: 10,
       intervalMs: 5000,
+      range: getDefaultTimeRange(),
       targets: [{ refId: 'A' }, { refId: 'B', datasource: { type: 'sample' } }],
     } as DataQueryRequest);
 
@@ -205,6 +222,7 @@ describe('DataSourceWithBackend', () => {
       targets: [{ refId: 'A' }, { refId: 'B', datasource: { type: 'sample' } }],
       hideFromInspector: true,
       dashboardUID: 'dashA',
+      range: getDefaultTimeRange(),
       panelId: 123,
     } as DataQueryRequest);
 
@@ -214,6 +232,7 @@ describe('DataSourceWithBackend', () => {
     expect(args).toMatchInlineSnapshot(`
       {
         "data": {
+          "from": "1697133600000",
           "queries": [
             {
               "applyTemplateVariablesCalled": true,
@@ -240,6 +259,7 @@ describe('DataSourceWithBackend', () => {
               "refId": "B",
             },
           ],
+          "to": "1697155200000",
         },
         "headers": {
           "X-Dashboard-Uid": "dashA",
@@ -330,6 +350,63 @@ describe('DataSourceWithBackend', () => {
     });
   });
 
+  test('check that queries can skip the query cache', () => {
+    const { mock, ds } = createMockDatasource();
+    ds.query({
+      maxDataPoints: 10,
+      intervalMs: 5000,
+      targets: [{ refId: 'A' }],
+      dashboardUID: 'dashA',
+      panelId: 123,
+      range: getDefaultTimeRange(),
+      skipQueryCache: true,
+      requestId: 'request-123',
+      interval: '5s',
+      scopedVars: {},
+      timezone: '',
+      app: '',
+      startTime: 0,
+    });
+
+    const args = mock.calls[0][0];
+
+    expect(mock.calls.length).toBe(1);
+    expect(args).toMatchInlineSnapshot(`
+      {
+        "data": {
+          "from": "1697133600000",
+          "queries": [
+            {
+              "applyTemplateVariablesCalled": true,
+              "datasource": {
+                "type": "dummy",
+                "uid": "abc",
+              },
+              "datasourceId": 1234,
+              "filters": undefined,
+              "intervalMs": 5000,
+              "maxDataPoints": 10,
+              "queryCachingTTL": undefined,
+              "refId": "A",
+            },
+          ],
+          "to": "1697155200000",
+        },
+        "headers": {
+          "X-Cache-Skip": "true",
+          "X-Dashboard-Uid": "dashA",
+          "X-Datasource-Uid": "abc",
+          "X-Panel-Id": "123",
+          "X-Plugin-Id": "dummy",
+        },
+        "hideFromInspector": false,
+        "method": "POST",
+        "requestId": "request-123",
+        "url": "/api/ds/query?ds_type=dummy&requestId=request-123",
+      }
+    `);
+  });
+
   describe('isExpressionReference', () => {
     test('check all possible expression references', () => {
       expect(isExpressionReference('__expr__')).toBeTruthy(); // New UID
@@ -353,6 +430,7 @@ describe('DataSourceWithBackend', () => {
         dashboardUID: 'dashA',
         panelId: 123,
         queryGroupId: 'abc',
+        range: getDefaultTimeRange(),
       } as DataQueryRequest;
 
       ds.query(request);
@@ -371,6 +449,7 @@ describe('DataSourceWithBackend', () => {
         dashboardUID: 'dashA',
         panelId: 123,
         queryGroupId: 'abc',
+        range: getDefaultTimeRange(),
       } as DataQueryRequest;
 
       ds.query(request);
