@@ -57,6 +57,50 @@ interface StoryProps extends Partial<Props> {
   valueText: string;
 }
 
+export const ApplyNoValue: Story<StoryProps> = ({
+  valueText,
+  title,
+  colorMode,
+  graphMode,
+  height,
+  width,
+  color,
+  textMode,
+  justifyMode,
+}) => {
+  const theme = useTheme2();
+  const sparkline: FieldSparkline = {
+    y: {
+      name: '',
+      values: [1, 2, 3, null, null],
+      type: FieldType.number,
+      state: { range: { min: 1, max: 4, delta: 3 } },
+      config: {
+        noValue: '0',
+      },
+    },
+  };
+
+  return (
+    <BigValue
+      theme={theme}
+      width={width}
+      height={height}
+      colorMode={colorMode}
+      graphMode={graphMode}
+      textMode={textMode}
+      justifyMode={justifyMode}
+      value={{
+        text: valueText,
+        numeric: 5022,
+        color: color,
+        title,
+      }}
+      sparkline={graphMode === BigValueGraphMode.None ? undefined : sparkline}
+    />
+  );
+};
+
 export const Basic: Story<StoryProps> = ({
   valueText,
   title,
@@ -111,4 +155,16 @@ Basic.args = {
   textMode: BigValueTextMode.Auto,
 };
 
+ApplyNoValue.args = {
+  valueText: '$5022',
+  title: 'Total Earnings',
+  colorMode: BigValueColorMode.Value,
+  graphMode: BigValueGraphMode.Area,
+  justifyMode: BigValueJustifyMode.Auto,
+  width: 400,
+  height: 300,
+  color: 'red',
+  textMode: BigValueTextMode.Auto,
+};
+
 export default meta;
