@@ -6,7 +6,9 @@ import React, { PureComponent } from 'react';
 import { SelectableValue } from '@grafana/data';
 
 import { Icon } from '../Icon/Icon';
+import { IconButton } from '../IconButton/IconButton';
 import { Input } from '../Input/Input';
+import { Stack } from '../Layout/Stack/Stack';
 import { Select } from '../Select/Select';
 
 import { onChangeCascader } from './optionMappings';
@@ -38,6 +40,10 @@ export interface CascaderProps {
       cascader is hidden after selection. */
   hideActiveLevelLabel?: boolean;
   disabled?: boolean;
+  /** ID for the underlying Select/Cascader component */
+  id?: string;
+  /** Whether you can clear the selected value or not */
+  isClearable?: boolean;
 }
 
 interface CascaderState {
@@ -46,6 +52,7 @@ interface CascaderState {
   //Array for cascade navigation
   rcValue: SelectableValue<string[]>;
   activeLabel: string;
+  inputValue: string;
 }
 
 export interface CascaderOption {
@@ -84,6 +91,7 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
       focusCascade: false,
       rcValue,
       activeLabel,
+      inputValue: '',
     };
   }
 
@@ -141,6 +149,7 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
       focusCascade: true,
       activeLabel,
       isSearching: false,
+      inputValue: activeLabel,
     };
     this.setState(state);
     this.props.onSelect(selectedOptions[selectedOptions.length - 1].value);
@@ -152,6 +161,7 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
     const activeLabel = this.props.displayAllSelectedLevels ? obj.label : obj.singleLabel || '';
     const state: CascaderState = {
       activeLabel: activeLabel,
+      inputValue: activeLabel,
       rcValue: { value: valueArray, label: activeLabel },
       isSearching: false,
       focusCascade: false,
@@ -163,6 +173,7 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
   onCreateOption = (value: string) => {
     this.setState({
       activeLabel: value,
+      inputValue: value,
       rcValue: [],
       isSearching: false,
     });
@@ -192,26 +203,36 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
   };
 
   onInputKeyDown = (e: React.KeyboardEvent<HTMLInputElement>) => {
-    if (['ArrowDown', 'ArrowUp', 'Enter', 'ArrowLeft', 'ArrowRight', 'Backspace'].includes(e.key)) {
+    if (['ArrowDown', 'ArrowUp', 'Enter', 'ArrowLeft', 'ArrowRight'].includes(e.key)) {
       return;
     }
+    const { activeLabel } = this.state;
     this.setState({
       focusCascade: false,
       isSearching: true,
+      inputValue: activeLabel,
     });
   };
 
   onSelectInputChange = (value: string) => {
-    if (value === '') {
-      this.setState({
-        isSearching: false,
-      });
-    }
+    this.setState({
+      inputValue: value,
+    });
   };
 
   render() {
-    const { allowCustomValue, formatCreateLabel, placeholder, width, changeOnSelect, options, disabled } = this.props;
-    const { focusCascade, isSearching, rcValue, activeLabel } = this.state;
+    const {
+      allowCustomValue,
+      formatCreateLabel,
+      placeholder,
+      width,
+      changeOnSelect,
+      options,
+      disabled,
+      id,
+      isClearable,
+    } = this.props;
+    const { focusCascade, isSearching, rcValue, activeLabel, inputValue } = this.state;
 
     const searchableOptions = this.getSearchableOptions(options);
 
@@ -230,6 +251,8 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
             width={width}
             onInputChange={this.onSelectInputChange}
             disabled={disabled}
+            inputValue={inputValue}
+            inputId={id}
           />
         ) : (
           <RCCascader
@@ -252,13 +275,24 @@ export class Cascader extends PureComponent<CascaderProps, CascaderState> {
                 onKeyDown={this.onInputKeyDown}
                 onChange={() => {}}
                 suffix={
-                  focusCascade ? (
-                    <Icon name="angle-up" />
-                  ) : (
-                    <Icon name="angle-down" style={{ marginBottom: 0, marginLeft: '4px' }} />
-                  )
+                  <Stack gap={0.5}>
+                    {isClearable && activeLabel !== '' && (
+                      <IconButton
+                        name="times"
+                        aria-label="Clear selection"
+                        onClick={(e) => {
+                          e.preventDefault();
+                          e.stopPropagation();
+                          this.setState({ rcValue: [], activeLabel: '', inputValue: '' });
+                          this.props.onSelect('');
+                        }}
+                      />
+                    )}
+                    <Icon name={focusCascade ? 'angle-up' : 'angle-down'} />
+                  </Stack>
                 }
                 disabled={disabled}
+                id={id}
               />
             </div>
           </RCCascader>
