@@ -2,15 +2,12 @@ import { action } from '@storybook/addon-actions';
 import { Meta } from '@storybook/react';
 import React from 'react';
 
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
-
 import { ClickOutsideWrapper } from './ClickOutsideWrapper';
 import mdx from './ClickOutsideWrapper.mdx';
 
 const meta: Meta<typeof ClickOutsideWrapper> = {
   title: 'Layout/ClickOutsideWrapper',
   component: ClickOutsideWrapper,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
@@ -20,8 +17,13 @@ const meta: Meta<typeof ClickOutsideWrapper> = {
 
 export const basic = () => {
   return (
-    <ClickOutsideWrapper onClick={action('Clicked outside')}>
-      <div style={{ width: '300px', border: '1px solid grey', padding: '20px' }}>Container</div>
+    <ClickOutsideWrapper
+      onClick={() => {
+        action('Clicked outside!')();
+        window.alert('Clicked outside!');
+      }}
+    >
+      <div style={{ width: '300px', border: '1px solid grey', padding: '20px' }}>Click outside this box!</div>
     </ClickOutsideWrapper>
   );
 };
