@@ -2,7 +2,6 @@ import { action } from '@storybook/addon-actions';
 import { useArgs } from '@storybook/client-api';
 import { Meta, StoryFn } from '@storybook/react';
 
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { renderComponentWithTheme } from '../../utils/storybook/withTheme';
 
 import mdx from './ColorPicker.mdx';
@@ -11,7 +10,6 @@ import SpectrumPalette from './SpectrumPalette';
 const meta: Meta<typeof SpectrumPalette> = {
   title: 'Pickers and Editors/ColorPicker/Palettes/SpectrumPalette',
   component: SpectrumPalette,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
