@@ -24,11 +24,11 @@ export const DataLinksContextMenu = ({ children, links, style }: DataLinksContex
   const itemsGroup: MenuItemsGroup[] = [{ items: linkModelToContextMenuItems(links), label: 'Data links' }];
   const linksCounter = itemsGroup[0].items.length;
   const renderMenuGroupItems = () => {
-    return itemsGroup.map((group, index) => (
-      <MenuGroup key={`${group.label}${index}`} label={group.label}>
-        {(group.items || []).map((item) => (
+    return itemsGroup.map((group, groupIdx) => (
+      <MenuGroup key={`${group.label}${groupIdx}`} label={group.label}>
+        {(group.items || []).map((item, itemIdx) => (
           <MenuItem
-            key={item.label}
+            key={`${group.label}-${groupIdx}-${itemIdx}}`}
             url={item.url}
             label={item.label}
             target={item.target}
@@ -63,7 +63,7 @@ export const DataLinksContextMenu = ({ children, links, style }: DataLinksContex
         target={linkModel.target}
         title={linkModel.title}
         style={{ ...style, overflow: 'hidden', display: 'flex' }}
-        aria-label={selectors.components.DataLinksContextMenu.singleLink}
+        data-testid={selectors.components.DataLinksContextMenu.singleLink}
       >
         {children({})}
       </a>
