@@ -1,7 +1,8 @@
 import { css } from '@emotion/css';
-import React, { ChangeEvent } from 'react';
+import { autoUpdate, flip, shift, useClick, useDismiss, useFloating, useInteractions } from '@floating-ui/react';
+import React, { ChangeEvent, useState } from 'react';
 
-import { dateTime } from '@grafana/data';
+import { GrafanaTheme2, dateTime } from '@grafana/data';
 
 import { useStyles2 } from '../../../themes';
 import { Props as InputProps, Input } from '../../Input/Input';
@@ -35,17 +36,41 @@ export const DatePickerWithInput = ({
   placeholder = 'Date',
   ...rest
 }: DatePickerWithInputProps) => {
-  const [open, setOpen] = React.useState(false);
+  const [open, setOpen] = useState(false);
   const styles = useStyles2(getStyles);
 
+  // the order of middleware is important!
+  // see https://floating-ui.com/docs/arrow#order
+  const middleware = [
+    flip({
+      // see https://floating-ui.com/docs/flip#combining-with-shift
+      crossAxis: false,
+      boundary: document.body,
+    }),
+    shift(),
+  ];
+
+  const { context, refs, floatingStyles } = useFloating({
+    open,
+    placement: 'bottom-start',
+    onOpenChange: setOpen,
+    middleware,
+    whileElementsMounted: autoUpdate,
+    strategy: 'fixed',
+  });
+
+  const click = useClick(context);
+  const dismiss = useDismiss(context);
+  const { getReferenceProps, getFloatingProps } = useInteractions([dismiss, click]);
+
   return (
     <div className={styles.container}>
       <Input
+        ref={refs.setReference}
         type="text"
         autoComplete={'off'}
         placeholder={placeholder}
         value={value ? formatDate(value) : value}
-        onClick={() => setOpen(true)}
         onChange={(ev: ChangeEvent<HTMLInputElement>) => {
           // Allow resetting the date
           if (ev.target.value === '') {
@@ -54,25 +79,28 @@ export const DatePickerWithInput = ({
         }}
         className={styles.input}
         {...rest}
+        {...getReferenceProps()}
       />
-      <DatePicker
-        isOpen={open}
-        value={value && typeof value !== 'string' ? value : dateTime().toDate()}
-        minDate={minDate}
-        maxDate={maxDate}
-        onChange={(ev) => {
-          onChange(ev);
-          if (closeOnSelect) {
-            setOpen(false);
-          }
-        }}
-        onClose={() => setOpen(false)}
-      />
+      <div className={styles.popover} ref={refs.setFloating} style={floatingStyles} {...getFloatingProps()}>
+        <DatePicker
+          isOpen={open}
+          value={value && typeof value !== 'string' ? value : dateTime().toDate()}
+          minDate={minDate}
+          maxDate={maxDate}
+          onChange={(ev) => {
+            onChange(ev);
+            if (closeOnSelect) {
+              setOpen(false);
+            }
+          }}
+          onClose={() => setOpen(false)}
+        />
+      </div>
     </div>
   );
 };
 
-const getStyles = () => {
+const getStyles = (theme: GrafanaTheme2) => {
   return {
     container: css({
       position: 'relative',
@@ -84,5 +112,8 @@ const getStyles = () => {
         WebkitAppearance: 'none',
       },
     }),
+    popover: css({
+      zIndex: theme.zIndex.tooltip,
+    }),
   };
 };
