@@ -3,14 +3,11 @@ import { useArgs } from '@storybook/client-api';
 import { Meta, StoryFn } from '@storybook/react';
 import React from 'react';
 
-import { withCenteredStory } from '../../../utils/storybook/withCenteredStory';
-
 import { RelativeTimeRangePicker } from './RelativeTimeRangePicker';
 
 const meta: Meta<typeof RelativeTimeRangePicker> = {
   title: 'Pickers and Editors/TimePickers/RelativeTimeRangePicker',
   component: RelativeTimeRangePicker,
-  decorators: [withCenteredStory],
   parameters: {
     controls: {
       exclude: ['onChange'],
