@@ -2,10 +2,11 @@ import { css } from '@emotion/css';
 import React, { useCallback } from 'react';
 import Calendar from 'react-calendar';
 
-import { GrafanaTheme2, dateTimeParse, DateTime, TimeZone, getZone } from '@grafana/data';
+import { GrafanaTheme2, dateTimeParse, DateTime, TimeZone } from '@grafana/data';
 
 import { useStyles2 } from '../../../themes';
 import { Icon } from '../../Icon/Icon';
+import { adjustDateForReactCalendar } from '../utils/adjustDateForReactCalendar';
 
 import { TimePickerCalendarProps } from './TimePickerCalendar';
 
@@ -42,7 +43,8 @@ export function inputToValue(
   let toAsDate = to.isValid() ? to.toDate() : invalidDateDefault;
 
   if (timezone) {
-    [fromAsDate, toAsDate] = adjustDateForReactCalendar(fromAsDate, toAsDate, timezone);
+    fromAsDate = adjustDateForReactCalendar(fromAsDate, timezone);
+    toAsDate = adjustDateForReactCalendar(toAsDate, timezone);
   }
 
   if (fromAsDate > toAsDate) {
@@ -52,39 +54,6 @@ export function inputToValue(
   return [fromAsDate, toAsDate];
 }
 
-/**
- * React calendar doesn't support showing ranges in other time zones, so attempting to show
- * 10th midnight - 11th midnight in another time zone than your browsers will span three days
- * instead of two.
- *
- * This function adjusts the dates by "moving" the time to appear as if it's local.
- * e.g. make 5 PM New York "look like" 5 PM in the user's local browser time.
- * See also https://github.com/wojtekmaj/react-calendar/issues/511#issuecomment-835333976
- */
-function adjustDateForReactCalendar(from: Date, to: Date, timeZone: string): [Date, Date] {
-  const zone = getZone(timeZone);
-  if (!zone) {
-    return [from, to];
-  }
-
-  // get utc offset for timezone preference
-  const timezonePrefFromOffset = zone.utcOffset(from.getTime());
-  const timezonePrefToOffset = zone.utcOffset(to.getTime());
-
-  // get utc offset for local timezone
-  const localFromOffset = from.getTimezoneOffset();
-  const localToOffset = to.getTimezoneOffset();
-
-  // calculate difference between timezone preference and local timezone
-  // we keep these as separate variables in case one of them crosses a daylight savings boundary
-  const fromDiff = timezonePrefFromOffset - localFromOffset;
-  const toDiff = timezonePrefToOffset - localToOffset;
-
-  const newFromDate = new Date(from.getTime() - fromDiff * 1000 * 60);
-  const newToDate = new Date(to.getTime() - toDiff * 1000 * 60);
-  return [newFromDate, newToDate];
-}
-
 function useOnCalendarChange(onChange: (from: DateTime, to: DateTime) => void, timeZone?: TimeZone) {
   return useCallback<NonNullable<React.ComponentProps<typeof Calendar>['onChange']>>(
     (value) => {
