@@ -1,15 +1,12 @@
 import { Meta, StoryFn } from '@storybook/react';
 import React from 'react';
 
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
-
 import { Divider } from './Divider';
 import mdx from './Divider.mdx';
 
 const meta: Meta<typeof Divider> = {
   title: 'General/Divider',
   component: Divider,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
@@ -17,8 +14,14 @@ const meta: Meta<typeof Divider> = {
   },
 };
 
-export const Basic: StoryFn<typeof Divider> = ({ direction }) => {
-  return <Divider direction={direction} />;
+export const Basic: StoryFn<typeof Divider> = ({ direction, spacing }) => {
+  return (
+    <div style={{ display: direction === 'vertical' ? 'flex' : 'block', flexDirection: 'row', height: '50px' }}>
+      <div>My text here</div>
+      <Divider direction={direction} spacing={spacing} />
+      <div>My text here</div>
+    </div>
+  );
 };
 
 export const Examples: StoryFn<typeof Divider> = () => {
