@@ -2,7 +2,6 @@ import { Meta } from '@storybook/react';
 import React from 'react';
 
 import { StoryExample } from '../../utils/storybook/StoryExample';
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { Button } from '../Button';
 import { IconButton } from '../IconButton/IconButton';
 import { VerticalGroup } from '../Layout/Layout';
@@ -14,7 +13,6 @@ import mdx from './Dropdown.mdx';
 const meta: Meta<typeof Dropdown> = {
   title: 'Overlays/Dropdown',
   component: Dropdown,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
