@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
 import {
+  FloatingFocusManager,
   autoUpdate,
   flip,
   offset as floatingUIOffset,
@@ -9,7 +10,6 @@ import {
   useFloating,
   useInteractions,
 } from '@floating-ui/react';
-import { FocusScope } from '@react-aria/focus';
 import React, { useEffect, useRef, useState } from 'react';
 import { CSSTransition } from 'react-transition-group';
 
@@ -83,7 +83,7 @@ export const Dropdown = React.memo(({ children, overlay, placement, offset, onVi
       })}
       {show && (
         <Portal>
-          <FocusScope autoFocus restoreFocus contain>
+          <FloatingFocusManager context={context}>
             {/*
               this is handling bubbled events from the inner overlay
               see https://github.com/jsx-eslint/eslint-plugin-jsx-a11y/blob/main/docs/rules/no-static-element-interactions.md#case-the-event-handler-is-only-being-used-to-capture-bubbled-events
@@ -100,7 +100,7 @@ export const Dropdown = React.memo(({ children, overlay, placement, offset, onVi
                 <div ref={transitionRef}>{ReactUtils.renderOrCallToRender(overlay, { ...getFloatingProps() })}</div>
               </CSSTransition>
             </div>
-          </FocusScope>
+          </FloatingFocusManager>
         </Portal>
       )}
     </>
