@@ -3,14 +3,11 @@ import React from 'react';
 
 import { FileUpload } from '@grafana/ui';
 
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
-
 import mdx from './FileUpload.mdx';
 
 const meta: Meta<typeof FileUpload> = {
   title: 'Forms/FileUpload',
   component: FileUpload,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
