@@ -1,8 +1,6 @@
 import { Meta, StoryFn } from '@storybook/react';
 import React, { useState } from 'react';
 
-import { withCenteredStory } from '@grafana/ui/src/utils/storybook/withCenteredStory';
-
 import { getAvailableIcons } from '../../types';
 import { HorizontalGroup } from '../Layout/Layout';
 
@@ -12,7 +10,6 @@ import mdx from './FilterPill.mdx';
 const meta: Meta<typeof FilterPill> = {
   title: 'General/FilterPill',
   component: FilterPill,
-  decorators: [withCenteredStory],
   argTypes: {
     icon: { control: { type: 'select', options: getAvailableIcons() } },
     onClick: { action: 'Pill Clicked' },
