@@ -3,7 +3,7 @@ import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 
-import { stylesFactory, useStyles2 } from '../../themes';
+import { useStyles2 } from '../../themes';
 import { Alert, AlertVariant } from '../Alert/Alert';
 import { Icon } from '../Icon/Icon';
 
@@ -45,11 +45,9 @@ export const InfoBox = React.memo(
 
 InfoBox.displayName = 'InfoBox';
 
-const getStyles = stylesFactory((theme: GrafanaTheme2) => {
-  return {
-    docsLink: css({
-      display: 'inline-block',
-      marginTop: theme.spacing(2),
-    }),
-  };
+const getStyles = (theme: GrafanaTheme2) => ({
+  docsLink: css({
+    display: 'inline-block',
+    marginTop: theme.spacing(2),
+  }),
 });
