@@ -120,7 +120,8 @@ export type InteractiveTableHeaderTooltip = {
 
 export type FetchDataArgs<Data> = { sortBy: Array<SortingRule<Data>> };
 export type FetchDataFunc<Data> = ({ sortBy }: FetchDataArgs<Data>) => void;
-interface Props<TableData extends object> {
+
+interface BaseProps<TableData extends object> {
   className?: string;
   /**
    * Table's columns definition. Must be memoized.
@@ -140,12 +141,10 @@ interface Props<TableData extends object> {
   headerTooltips?: Record<string, InteractiveTableHeaderTooltip>;
   /**
    * Number of rows per page. A value of zero disables pagination. Defaults to 0.
+   * A React hooks error will be thrown if pageSize goes from greater than 0 to 0 or vice versa. If enabling pagination,
+   * make sure pageSize remains a non-zero value.
    */
   pageSize?: number;
-  /**
-   * Render function for the expanded row. if not provided, the tables rows will not be expandable.
-   */
-  renderExpandedRow?: (row: TableData) => ReactNode;
   /**
    * A custom function to fetch data when the table is sorted. If not provided, the table will be sorted client-side.
    * It's important for this function to have a stable identity, e.g. being wrapped into useCallback to prevent unnecessary
@@ -154,6 +153,24 @@ interface Props<TableData extends object> {
   fetchData?: FetchDataFunc<TableData>;
 }
 
+interface WithExpandableRow<TableData extends object> extends BaseProps<TableData> {
+  /**
+   * Render function for the expanded row. if not provided, the tables rows will not be expandable.
+   */
+  renderExpandedRow: (row: TableData) => ReactNode;
+  /**
+   * Whether to show the "Expand all" button. Depends on renderExpandedRow to be provided. Defaults to false.
+   */
+  showExpandAll?: boolean;
+}
+
+interface WithoutExpandableRow<TableData extends object> extends BaseProps<TableData> {
+  renderExpandedRow?: never;
+  showExpandAll?: never;
+}
+
+type Props<TableData extends object> = WithExpandableRow<TableData> | WithoutExpandableRow<TableData>;
+
 /** @alpha */
 export function InteractiveTable<TableData extends object>({
   className,
@@ -163,12 +180,13 @@ export function InteractiveTable<TableData extends object>({
   headerTooltips,
   pageSize = 0,
   renderExpandedRow,
+  showExpandAll = false,
   fetchData,
 }: Props<TableData>) {
   const styles = useStyles2(getStyles);
   const tableColumns = useMemo(() => {
-    return getColumns<TableData>(columns);
-  }, [columns]);
+    return getColumns<TableData>(columns, showExpandAll);
+  }, [columns, showExpandAll]);
   const id = useUniqueId();
   const getRowHTMLID = useCallback(
     (row: Row<TableData>) => {
@@ -180,7 +198,7 @@ export function InteractiveTable<TableData extends object>({
   const tableHooks: Array<PluginHook<TableData>> = [useSortBy, useExpanded];
 
   const multiplePages = data.length > pageSize;
-  const paginationEnabled = pageSize > 0 && multiplePages;
+  const paginationEnabled = pageSize > 0;
 
   if (paginationEnabled) {
     tableHooks.push(usePagination);
@@ -288,7 +306,7 @@ export function InteractiveTable<TableData extends object>({
           })}
         </tbody>
       </table>
-      {paginationEnabled && (
+      {paginationEnabled && multiplePages && (
         <span>
           <Pagination
             currentPage={tableInstance.state.pageIndex + 1}
