@@ -13,9 +13,7 @@ describe('SubMenu', () => {
       <MenuItem key="subitem2" label="subitem2" icon="apps" />,
     ];
 
-    render(
-      <SubMenu items={items} isOpen={true} openedWithArrow={false} setOpenedWithArrow={jest.fn()} close={jest.fn()} />
-    );
+    render(<SubMenu items={items} isOpen={true} close={jest.fn()} />);
 
     expect(screen.getByTestId(selectors.components.Menu.SubMenu.icon)).toBeInTheDocument();
 
