@@ -1,4 +1,5 @@
-import MonacoEditor, { loader as monacoEditorLoader, Monaco } from '@monaco-editor/react';
+import Editor, { loader as monacoEditorLoader, Monaco } from '@monaco-editor/react';
+import * as monaco from 'monaco-editor';
 import React, { useCallback } from 'react';
 
 import { useTheme2 } from '../../themes';
@@ -6,11 +7,8 @@ import { useTheme2 } from '../../themes';
 import defineThemes from './theme';
 import type { ReactMonacoEditorProps } from './types';
 
-monacoEditorLoader.config({
-  paths: {
-    vs: (window.__grafana_public_path__ ?? 'public/') + 'lib/monaco/min/vs',
-  },
-});
+// pass the monaco editor to the loader to bypass requirejs
+monacoEditorLoader.config({ monaco });
 
 export const ReactMonacoEditor = (props: ReactMonacoEditorProps) => {
   const { beforeMount } = props;
@@ -25,10 +23,6 @@ export const ReactMonacoEditor = (props: ReactMonacoEditorProps) => {
   );
 
   return (
-    <MonacoEditor
-      {...props}
-      theme={theme.isDark ? 'grafana-dark' : 'grafana-light'}
-      beforeMount={onMonacoBeforeMount}
-    />
+    <Editor {...props} theme={theme.isDark ? 'grafana-dark' : 'grafana-light'} beforeMount={onMonacoBeforeMount} />
   );
 };
