@@ -6,7 +6,6 @@ import {
   DashboardCursorSync,
   AnnotationEventUIModel,
   ThresholdsConfig,
-  SplitOpen,
   CoreApp,
   DataFrame,
   DataLinkPostProcessor,
@@ -70,13 +69,6 @@ export interface PanelContext {
    */
   onThresholdsChange?: (thresholds: ThresholdsConfig) => void;
 
-  /**
-   * onSplitOpen is used in Explore to open the split view. It can be used in panels which has intercations and used in Explore as well.
-   * For example TimeSeries panel.
-   * @deprecated will be removed in the future. It's not needed as visualization can just field.getLinks now
-   */
-  onSplitOpen?: SplitOpen;
-
   /** For instance state that can be shared between panel & options UI  */
   instanceState?: any;
 
