@@ -46,11 +46,11 @@ export const SegmentSection = ({
 };
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  label: css`
-    color: ${theme.colors.primary.text};
-  `,
-  fill: css`
-    flex-grow: 1;
-    margin-bottom: ${theme.spacing(0.5)};
-  `,
+  label: css({
+    color: theme.colors.primary.text,
+  }),
+  fill: css({
+    flexGrow: 1,
+    marginBottom: theme.spacing(0.5),
+  }),
 });
