@@ -3,8 +3,7 @@ import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 
-import { stylesFactory } from '../../themes';
-import { useTheme2 } from '../../themes/ThemeContext';
+import { useStyles2 } from '../../themes/ThemeContext';
 import { inputPadding } from '../Forms/commonStyles';
 import { getInputStyles } from '../Input/Input';
 
@@ -17,7 +16,20 @@ interface InputControlProps {
   innerProps: JSX.IntrinsicElements['div'];
 }
 
-const getInputControlStyles = stylesFactory((theme: GrafanaTheme2, invalid: boolean, withPrefix: boolean) => {
+export const InputControl = React.forwardRef<HTMLDivElement, React.PropsWithChildren<InputControlProps>>(
+  function InputControl({ focused, invalid, disabled, children, innerProps, prefix, ...otherProps }, ref) {
+    const styles = useStyles2(getInputControlStyles, invalid, !!prefix);
+
+    return (
+      <div className={styles.input} {...innerProps} ref={ref}>
+        {prefix && <div className={cx(styles.prefix)}>{prefix}</div>}
+        {children}
+      </div>
+    );
+  }
+);
+
+const getInputControlStyles = (theme: GrafanaTheme2, invalid: boolean, withPrefix: boolean) => {
   const styles = getInputStyles({ theme, invalid });
 
   return {
@@ -47,17 +59,4 @@ const getInputControlStyles = stylesFactory((theme: GrafanaTheme2, invalid: bool
       })
     ),
   };
-});
-
-export const InputControl = React.forwardRef<HTMLDivElement, React.PropsWithChildren<InputControlProps>>(
-  function InputControl({ focused, invalid, disabled, children, innerProps, prefix, ...otherProps }, ref) {
-    const theme = useTheme2();
-    const styles = getInputControlStyles(theme, invalid, !!prefix);
-    return (
-      <div className={styles.input} {...innerProps} ref={ref}>
-        {prefix && <div className={cx(styles.prefix)}>{prefix}</div>}
-        {children}
-      </div>
-    );
-  }
-);
+};
