@@ -5,7 +5,7 @@ import { SelectableValue, GrafanaTheme2 } from '@grafana/data';
 
 import { IconButton } from '../../components/IconButton/IconButton';
 import { TabsBar, Tab, TabContent } from '../../components/Tabs';
-import { stylesFactory, useTheme2 } from '../../themes';
+import { useStyles2, useTheme2 } from '../../themes';
 import { IconName } from '../../types/icon';
 import { CustomScrollbar } from '../CustomScrollbar/CustomScrollbar';
 
@@ -23,45 +23,16 @@ export interface TabbedContainerProps {
   onClose: () => void;
 }
 
-const getStyles = stylesFactory((theme: GrafanaTheme2) => {
-  return {
-    container: css({
-      height: '100%',
-    }),
-    tabContent: css({
-      padding: theme.spacing(2),
-      backgroundColor: theme.colors.background.primary,
-      height: `calc(100% - ${theme.components.menuTabs.height}px)`,
-    }),
-    close: css({
-      position: 'absolute',
-      right: '16px',
-      top: '5px',
-      cursor: 'pointer',
-      fontSize: theme.typography.size.lg,
-    }),
-    tabs: css({
-      paddingTop: theme.spacing(1),
-      borderColor: theme.colors.border.weak,
-      ul: {
-        marginLeft: theme.spacing(2),
-      },
-    }),
-  };
-});
-
-export function TabbedContainer(props: TabbedContainerProps) {
-  const [activeTab, setActiveTab] = useState(
-    props.tabs.some((tab) => tab.value === props.defaultTab) ? props.defaultTab : props.tabs?.[0].value
-  );
+export function TabbedContainer({ tabs, defaultTab, closeIconTooltip, onClose }: TabbedContainerProps) {
+  const [activeTab, setActiveTab] = useState(tabs.some((tab) => tab.value === defaultTab) ? defaultTab : tabs[0].value);
+  const styles = useStyles2(getStyles);
+  const theme = useTheme2();
 
   const onSelectTab = (item: SelectableValue<string>) => {
     setActiveTab(item.value!);
   };
 
-  const { tabs, onClose, closeIconTooltip } = props;
-  const theme = useTheme2();
-  const styles = getStyles(theme);
+  const autoHeight = `calc(100% - (${theme.components.menuTabs.height}px + ${theme.spacing(1)}))`;
 
   return (
     <div className={styles.container}>
@@ -77,9 +48,34 @@ export function TabbedContainer(props: TabbedContainerProps) {
         ))}
         <IconButton className={styles.close} onClick={onClose} name="times" tooltip={closeIconTooltip ?? 'Close'} />
       </TabsBar>
-      <CustomScrollbar autoHeightMin="100%">
+      <CustomScrollbar autoHeightMin={autoHeight} autoHeightMax={autoHeight}>
         <TabContent className={styles.tabContent}>{tabs.find((t) => t.value === activeTab)?.content}</TabContent>
       </CustomScrollbar>
     </div>
   );
 }
+
+const getStyles = (theme: GrafanaTheme2) => ({
+  container: css({
+    height: '100%',
+  }),
+  tabContent: css({
+    padding: theme.spacing(2),
+    backgroundColor: theme.colors.background.primary,
+    height: `100%`,
+  }),
+  close: css({
+    position: 'absolute',
+    right: '16px',
+    top: '5px',
+    cursor: 'pointer',
+    fontSize: theme.typography.size.lg,
+  }),
+  tabs: css({
+    paddingTop: theme.spacing(1),
+    borderColor: theme.colors.border.weak,
+    ul: {
+      marginLeft: theme.spacing(2),
+    },
+  }),
+});
