@@ -4,60 +4,85 @@ import React from 'react';
 
 import { applyFieldOverrides, createTheme, DataFrame, FieldType, toDataFrame } from '@grafana/data';
 
-import { Table } from './Table';
-import { Props } from './types';
+import { Icon } from '../Icon/Icon';
 
-function getDefaultDataFrame(): DataFrame {
-  const dataFrame = toDataFrame({
-    name: 'A',
-    fields: [
-      {
-        name: 'time',
-        type: FieldType.time,
-        values: [1609459200000, 1609470000000, 1609462800000, 1609466400000],
-        config: {
-          custom: {
-            filterable: false,
-          },
+import { Table } from './Table';
+import { CustomHeaderRendererProps, Props } from './types';
+
+// mock transition styles to ensure consistent behaviour in unit tests
+jest.mock('@floating-ui/react', () => ({
+  ...jest.requireActual('@floating-ui/react'),
+  useTransitionStyles: () => ({
+    styles: {},
+  }),
+}));
+
+const dataFrameData = {
+  name: 'A',
+  fields: [
+    {
+      name: 'time',
+      type: FieldType.time,
+      values: [1609459200000, 1609470000000, 1609462800000, 1609466400000],
+      config: {
+        custom: {
+          filterable: false,
         },
       },
-      {
-        name: 'temperature',
-        type: FieldType.number,
-        values: [10, NaN, 11, 12],
-        config: {
-          custom: {
-            filterable: false,
-          },
-          links: [
-            {
-              targetBlank: true,
-              title: 'Value link',
-              url: '${__value.text}',
-            },
-          ],
+    },
+    {
+      name: 'temperature',
+      type: FieldType.number,
+      values: [10, NaN, 11, 12],
+      config: {
+        custom: {
+          filterable: false,
+          headerComponent: (props: CustomHeaderRendererProps) => (
+            <span>
+              {props.defaultContent}
+              <Icon aria-label={'header-icon'} name={'ellipsis-v'} />
+            </span>
+          ),
         },
-      },
-      {
-        name: 'img',
-        type: FieldType.string,
-        values: ['data:image/png;base64,1', 'data:image/png;base64,2', 'data:image/png;base64,3'],
-        config: {
-          custom: {
-            filterable: false,
-            displayMode: 'image',
+        links: [
+          {
+            targetBlank: true,
+            title: 'Value link',
+            url: '${__value.text}',
           },
-          links: [
-            {
-              targetBlank: true,
-              title: 'Image link',
-              url: '${__value.text}',
-            },
-          ],
-        },
+        ],
       },
-    ],
-  });
+    },
+    {
+      name: 'img',
+      type: FieldType.string,
+      values: ['data:image/png;base64,1', 'data:image/png;base64,2', 'data:image/png;base64,3'],
+      config: {
+        custom: {
+          filterable: false,
+          displayMode: 'image',
+        },
+        links: [
+          {
+            targetBlank: true,
+            title: 'Image link',
+            url: '${__value.text}',
+          },
+        ],
+      },
+    },
+  ],
+};
+
+const fullDataFrame = toDataFrame(dataFrameData);
+
+const emptyValuesDataFrame = toDataFrame({
+  ...dataFrameData,
+  // Remove all values
+  fields: dataFrameData.fields.map((field) => ({ ...field, values: [] })),
+});
+
+function getDataFrame(dataFrame: DataFrame): DataFrame {
   return applyOverrides(dataFrame);
 }
 
@@ -68,7 +93,7 @@ function applyOverrides(dataFrame: DataFrame) {
       defaults: {},
       overrides: [],
     },
-    replaceVariables: (value, vars, format) => {
+    replaceVariables: (value, vars, _format) => {
       return vars && value === '${__value.text}' ? '${__value.text} interpolation' : value;
     },
     timeZone: 'utc',
@@ -83,7 +108,7 @@ function getTestContext(propOverrides: Partial<Props> = {}) {
   const onColumnResize = jest.fn();
   const props: Props = {
     ariaLabel: 'aria-label',
-    data: getDefaultDataFrame(),
+    data: getDataFrame(fullDataFrame),
     height: 600,
     width: 800,
     onSortByChange,
@@ -128,16 +153,53 @@ function getRowsData(rows: HTMLElement[]): Object[] {
 }
 
 describe('Table', () => {
-  describe('when mounted without data', () => {
-    it('then no data to show should be displayed', () => {
-      getTestContext({ data: toDataFrame([]) });
-      expect(getTable()).toBeInTheDocument();
-      expect(screen.queryByRole('row')).not.toBeInTheDocument();
-      expect(screen.getByText(/No data/i)).toBeInTheDocument();
+  describe('when mounted with EMPTY data', () => {
+    describe('and Standard Options `No value` value is NOT set', () => {
+      it('the default `no data` message should be displayed', () => {
+        getTestContext({ data: toDataFrame([]) });
+        expect(getTable()).toBeInTheDocument();
+        expect(screen.queryByRole('row')).not.toBeInTheDocument();
+        expect(screen.getByText(/No data/i)).toBeInTheDocument();
+      });
+    });
+
+    describe('and Standard Options `No value` value IS set', () => {
+      it('the `No value` Standard Options message should be displayed', () => {
+        const noValuesDisplayText = 'All healthy';
+        getTestContext({
+          data: toDataFrame([]),
+          fieldConfig: { defaults: { noValue: noValuesDisplayText }, overrides: [] },
+        });
+        expect(getTable()).toBeInTheDocument();
+        expect(screen.queryByRole('row')).not.toBeInTheDocument();
+        expect(screen.getByText(noValuesDisplayText)).toBeInTheDocument();
+      });
     });
   });
 
   describe('when mounted with data', () => {
+    describe('but empty values', () => {
+      describe('and Standard Options `No value` value is NOT set', () => {
+        it('the default `no data` message should be displayed', () => {
+          getTestContext({ data: getDataFrame(emptyValuesDataFrame) });
+          expect(getTable()).toBeInTheDocument();
+          expect(screen.getByText(/No data/i)).toBeInTheDocument();
+        });
+      });
+
+      describe('and Standard Options `No value` value IS set', () => {
+        it('the `No value` Standard Options message should be displayed', () => {
+          const noValuesDisplayText = 'All healthy';
+          getTestContext({
+            data: getDataFrame(emptyValuesDataFrame),
+            fieldConfig: { defaults: { noValue: noValuesDisplayText }, overrides: [] },
+          });
+          expect(getTable()).toBeInTheDocument();
+          expect(screen.getByText(noValuesDisplayText)).toBeInTheDocument();
+        });
+      });
+    });
+
     it('then correct rows should be rendered', () => {
       getTestContext();
       expect(getTable()).toBeInTheDocument();
@@ -184,6 +246,19 @@ describe('Table', () => {
     });
   });
 
+  describe('custom header', () => {
+    it('Should be rendered', async () => {
+      getTestContext();
+
+      await userEvent.click(within(getColumnHeader(/temperature/)).getByText(/temperature/i));
+      await userEvent.click(within(getColumnHeader(/temperature/)).getByText(/temperature/i));
+
+      const rows = within(getTable()).getAllByRole('row');
+      expect(rows).toHaveLength(5);
+      expect(within(rows[0]).getByLabelText('header-icon')).toBeInTheDocument();
+    });
+  });
+
   describe('on filtering', () => {
     it('the rows should be filtered', async () => {
       getTestContext({
@@ -343,7 +418,7 @@ describe('Table', () => {
       const onColumnResize = jest.fn();
       const props: Props = {
         ariaLabel: 'aria-label',
-        data: getDefaultDataFrame(),
+        data: getDataFrame(fullDataFrame),
         height: 600,
         width: 800,
         onSortByChange,
@@ -485,7 +560,7 @@ describe('Table', () => {
       const onColumnResize = jest.fn();
       const props: Props = {
         ariaLabel: 'aria-label',
-        data: getDefaultDataFrame(),
+        data: getDataFrame(fullDataFrame),
         height: 600,
         width: 800,
         onSortByChange,
@@ -541,7 +616,7 @@ describe('Table', () => {
           })
         );
 
-      const defaultFrame = getDefaultDataFrame();
+      const defaultFrame = getDataFrame(fullDataFrame);
 
       getTestContext({
         data: applyOverrides({
