@@ -2,15 +2,12 @@ import { action } from '@storybook/addon-actions';
 import { Meta, StoryFn } from '@storybook/react';
 import React from 'react';
 
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
-
 import { Tag } from './Tag';
 import mdx from './Tag.mdx';
 
 const meta: Meta<typeof Tag> = {
   title: 'Forms/Tags/Tag',
   component: Tag,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
