@@ -2,7 +2,6 @@ import { Meta, StoryFn } from '@storybook/react';
 import React, { useState } from 'react';
 
 import { StoryExample } from '../../utils/storybook/StoryExample';
-import { withCenteredStory } from '../../utils/storybook/withCenteredStory';
 import { VerticalGroup } from '../Layout/Layout';
 
 import { TagsInput } from './TagsInput';
@@ -11,7 +10,6 @@ import mdx from './TagsInput.mdx';
 const meta: Meta<typeof TagsInput> = {
   title: 'Forms/TagsInput',
   component: TagsInput,
-  decorators: [withCenteredStory],
   parameters: {
     docs: {
       page: mdx,
