@@ -2,6 +2,7 @@ import { Meta, StoryFn } from '@storybook/react';
 import React from 'react';
 
 import { Button } from '../Button';
+import { Stack } from '../Layout/Stack/Stack';
 import mdx from '../Tooltip/Tooltip.mdx';
 
 import { Tooltip } from './Tooltip';
@@ -62,6 +63,23 @@ export const Basic: StoryFn<typeof Tooltip> = ({ content, ...args }) => {
   );
 };
 
+export const OverflowViewport: StoryFn<typeof Tooltip> = ({}) => {
+  const content = () => <div>A really long tooltip that will overflow the viewport.</div>;
+
+  return (
+    <Stack justifyContent={'flex-end'}>
+      <Stack direction="column" alignItems={'flex-end'}>
+        <Tooltip content="Static string tooltip" placement="bottom">
+          <Button>Static string tooltip</Button>
+        </Tooltip>
+        <Tooltip content={content} placement="bottom">
+          <Button>Lazy content defined in a function</Button>
+        </Tooltip>
+      </Stack>
+    </Stack>
+  );
+};
+
 Basic.args = {
   content: 'This is a tooltip',
   theme: 'info',
