@@ -69,7 +69,7 @@ export const LegendTableItem = ({
     <tr className={cx(styles.row, className)}>
       <td>
         <span className={styles.itemWrapper}>
-          <VizLegendSeriesIcon color={item.color} seriesName={item.label} readonly={readonly} />
+          <VizLegendSeriesIcon color={item.color} seriesName={item.fieldName ?? item.label} readonly={readonly} />
           <button
             disabled={readonly}
             type="button"
@@ -126,6 +126,7 @@ const getStyles = (theme: GrafanaTheme2) => {
       maxWidth: '600px',
       textOverflow: 'ellipsis',
       overflow: 'hidden',
+      userSelect: 'text',
     }),
     labelDisabled: css({
       label: 'LegendLabelDisabled',
