@@ -8,7 +8,7 @@ import {
   VisibilityMode,
   ScaleOrientation,
   ScaleDirection,
-  GraphTresholdsStyleMode,
+  GraphThresholdsStyleMode,
   ScaleDistribution,
 } from '@grafana/schema';
 
@@ -379,8 +379,6 @@ describe('UPlotConfigBuilder', () => {
       max: 100,
     });
 
-    expect(builder.getConfig().scales!['scale-y']!.auto).toEqual(false);
-
     builder.addScale({
       isTime: false,
       scaleKey: 'scale-y2',
@@ -391,6 +389,7 @@ describe('UPlotConfigBuilder', () => {
       softMin: -50,
     });
 
+    expect(builder.getConfig().scales!['scale-y']!.auto).toEqual(false);
     expect(builder.getConfig().scales!['scale-y2']!.auto).toEqual(true);
   });
 
@@ -812,7 +811,7 @@ describe('UPlotConfigBuilder', () => {
           steps: [],
         },
         config: {
-          mode: GraphTresholdsStyleMode.Area,
+          mode: GraphThresholdsStyleMode.Area,
         },
         theme: darkTheme,
       });
@@ -823,7 +822,7 @@ describe('UPlotConfigBuilder', () => {
           steps: [],
         },
         config: {
-          mode: GraphTresholdsStyleMode.Area,
+          mode: GraphThresholdsStyleMode.Area,
         },
         theme: darkTheme,
       });
