@@ -1,17 +1,8 @@
 import { merge } from 'lodash';
 import uPlot, { Cursor, Band, Hooks, Select, AlignedData, Padding, Series } from 'uplot';
 
-import {
-  DataFrame,
-  DefaultTimeZone,
-  EventBus,
-  Field,
-  getTimeZoneInfo,
-  GrafanaTheme2,
-  TimeRange,
-  TimeZone,
-} from '@grafana/data';
-import { AxisPlacement } from '@grafana/schema';
+import { DataFrame, DefaultTimeZone, Field, getTimeZoneInfo, GrafanaTheme2, TimeRange, TimeZone } from '@grafana/data';
+import { AxisPlacement, VizOrientation } from '@grafana/schema';
 
 import { FacetedData, PlotConfig, PlotTooltipInterpolator } from '../types';
 import { DEFAULT_PLOT_CONFIG, getStackingBands, pluginLog, StackingGroup } from '../utils';
@@ -306,7 +297,6 @@ type UPlotConfigPrepOpts<T extends Record<string, unknown> = {}> = {
   theme: GrafanaTheme2;
   timeZones: TimeZone[];
   getTimeRange: () => TimeRange;
-  eventBus: EventBus;
   allFrames: DataFrame[];
   renderers?: Renderers;
   tweakScale?: (opts: ScaleProps, forField: Field) => ScaleProps;
@@ -314,6 +304,7 @@ type UPlotConfigPrepOpts<T extends Record<string, unknown> = {}> = {
   // Identifies the shared key for uPlot cursor sync
   eventsScope?: string;
   hoverProximity?: number;
+  orientation?: VizOrientation;
 } & T;
 
 /** @alpha */
