@@ -3,6 +3,11 @@ import uPlot, { Options, AlignedData } from 'uplot';
 
 import { UPlotConfigBuilder } from './config/UPlotConfigBuilder';
 
+/**
+ * @internal -- not a public API
+ */
+export const FIXED_UNIT = '__fixed';
+
 export type PlotConfig = Pick<
   Options,
   'mode' | 'series' | 'scales' | 'axes' | 'cursor' | 'bands' | 'hooks' | 'select' | 'tzDate' | 'padding'
