@@ -4,9 +4,6 @@ import uPlot from 'uplot';
 import {
   DashboardCursorSync,
   DataFrame,
-  DataHoverClearEvent,
-  DataHoverEvent,
-  DataHoverPayload,
   FieldConfig,
   FieldType,
   formattedValueToString,
@@ -81,7 +78,6 @@ export const preparePlotConfigBuilder: UPlotConfigPrepFn<{
   theme,
   timeZones,
   getTimeRange,
-  eventBus,
   sync,
   allFrames,
   renderers,
@@ -107,7 +103,6 @@ export const preparePlotConfigBuilder: UPlotConfigPrepFn<{
   }
 
   const xScaleKey = 'x';
-  let xScaleUnit = '_x';
   let yScaleKey = '';
 
   const xFieldAxisPlacement =
@@ -115,7 +110,6 @@ export const preparePlotConfigBuilder: UPlotConfigPrepFn<{
   const xFieldAxisShow = xField.config.custom?.axisPlacement !== AxisPlacement.Hidden;
 
   if (xField.type === FieldType.time) {
-    xScaleUnit = 'time';
     builder.addScale({
       scaleKey: xScaleKey,
       orientation: ScaleOrientation.Horizontal,
@@ -173,11 +167,6 @@ export const preparePlotConfigBuilder: UPlotConfigPrepFn<{
       });
     }
   } else {
-    // Not time!
-    if (xField.config.unit) {
-      xScaleUnit = xField.config.unit;
-    }
-
     builder.addScale({
       scaleKey: xScaleKey,
       orientation: ScaleOrientation.Horizontal,
@@ -609,41 +598,9 @@ export const preparePlotConfigBuilder: UPlotConfigPrepFn<{
   };
 
   if (sync && sync() !== DashboardCursorSync.Off) {
-    const payload: DataHoverPayload = {
-      point: {
-        [xScaleKey]: null,
-        [yScaleKey]: null,
-      },
-      data: frame,
-    };
-
-    const hoverEvent = new DataHoverEvent(payload);
     cursor.sync = {
       key: eventsScope,
-      filters: {
-        pub: (type: string, src: uPlot, x: number, y: number, w: number, h: number, dataIdx: number) => {
-          if (sync && sync() === DashboardCursorSync.Off) {
-            return false;
-          }
-
-          payload.rowIndex = dataIdx;
-          if (x < 0 && y < 0) {
-            payload.point[xScaleUnit] = null;
-            payload.point[yScaleKey] = null;
-            eventBus.publish(new DataHoverClearEvent());
-          } else {
-            // convert the points
-            payload.point[xScaleUnit] = src.posToVal(x, xScaleKey);
-            payload.point[yScaleKey] = src.posToVal(y, yScaleKey);
-            payload.point.panelRelY = y > 0 ? y / h : 1; // used by old graph panel to position tooltip
-            eventBus.publish(hoverEvent);
-            hoverEvent.payload.down = undefined;
-          }
-          return true;
-        },
-      },
-      scales: [xScaleKey, yScaleKey],
-      // match: [() => true, (a, b) => a === b],
+      scales: [xScaleKey, null],
     };
   }
 
