@@ -7,7 +7,6 @@ import (
 	"net/http"
 
 	"github.com/grafana/grafana/pkg/api/response"
-	"github.com/grafana/grafana/pkg/services/alerting"
 	"github.com/grafana/grafana/pkg/services/dashboards"
 	"github.com/grafana/grafana/pkg/services/pluginsintegration/pluginstore"
 	"github.com/grafana/grafana/pkg/util"
@@ -30,11 +29,6 @@ func ToDashboardErrorResponse(ctx context.Context, pluginStore pluginstore.Store
 		return response.Error(http.StatusBadRequest, err.Error(), nil)
 	}
 
-	var validationErr alerting.ValidationError
-	if ok := errors.As(err, &validationErr); ok {
-		return response.Error(http.StatusUnprocessableEntity, validationErr.Error(), err)
-	}
-
 	var pluginErr dashboards.UpdatePluginDashboardError
 	if ok := errors.As(err, &pluginErr); ok {
 		message := fmt.Sprintf("The dashboard belongs to plugin %s.", pluginErr.PluginId)
