@@ -34,7 +34,7 @@ func (hs *HTTPServer) SignUp(c *contextmodel.ReqContext) response.Response {
 		return response.Error(http.StatusBadRequest, "bad request data", err)
 	}
 	if !hs.Cfg.AllowUserSignUp {
-		return response.Error(401, "User signup is disabled", nil)
+		return response.Error(http.StatusUnauthorized, "User signup is disabled", nil)
 	}
 
 	form.Email, err = ValidateAndNormalizeEmail(form.Email)
@@ -45,7 +45,7 @@ func (hs *HTTPServer) SignUp(c *contextmodel.ReqContext) response.Response {
 	existing := user.GetUserByLoginQuery{LoginOrEmail: form.Email}
 	_, err = hs.userService.GetByLogin(c.Req.Context(), &existing)
 	if err == nil {
-		return response.Error(422, "User with same email address already exists", nil)
+		return response.Error(http.StatusUnprocessableEntity, "User with same email address already exists", nil)
 	}
 
 	userID, errID := identity.UserIdentifier(c.SignedInUser.GetNamespacedID())
@@ -60,19 +60,19 @@ func (hs *HTTPServer) SignUp(c *contextmodel.ReqContext) response.Response {
 	cmd.InvitedByUserID = userID
 	cmd.Code, err = util.GetRandomString(20)
 	if err != nil {
-		return response.Error(500, "Failed to generate random string", err)
+		return response.Error(http.StatusInternalServerError, "Failed to generate random string", err)
 	}
 	cmd.RemoteAddr = c.RemoteAddr()
 
 	if _, err := hs.tempUserService.CreateTempUser(c.Req.Context(), &cmd); err != nil {
-		return response.Error(500, "Failed to create signup", err)
+		return response.Error(http.StatusInternalServerError, "Failed to create signup", err)
 	}
 
 	if err := hs.bus.Publish(c.Req.Context(), &events.SignUpStarted{
 		Email: form.Email,
 		Code:  cmd.Code,
 	}); err != nil {
-		return response.Error(500, "Failed to publish event", err)
+		return response.Error(http.StatusInternalServerError, "Failed to publish event", err)
 	}
 
 	metrics.MApiUserSignUpStarted.Inc()
@@ -86,7 +86,7 @@ func (hs *HTTPServer) SignUpStep2(c *contextmodel.ReqContext) response.Response
 		return response.Error(http.StatusBadRequest, "bad request data", err)
 	}
 	if !hs.Cfg.AllowUserSignUp {
-		return response.Error(401, "User signup is disabled", nil)
+		return response.Error(http.StatusUnauthorized, "User signup is disabled", nil)
 	}
 
 	form.Email = strings.TrimSpace(form.Email)
@@ -111,10 +111,10 @@ func (hs *HTTPServer) SignUpStep2(c *contextmodel.ReqContext) response.Response
 	usr, err := hs.userService.Create(c.Req.Context(), &createUserCmd)
 	if err != nil {
 		if errors.Is(err, user.ErrUserAlreadyExists) {
-			return response.Error(401, "User with same email address already exists", nil)
+			return response.Error(http.StatusUnauthorized, "User with same email address already exists", nil)
 		}
 
-		return response.Error(500, "Failed to create user", err)
+		return response.Error(http.StatusInternalServerError, "Failed to create user", err)
 	}
 
 	// publish signup event
@@ -122,7 +122,7 @@ func (hs *HTTPServer) SignUpStep2(c *contextmodel.ReqContext) response.Response
 		Email: usr.Email,
 		Name:  usr.NameOrFallback(),
 	}); err != nil {
-		return response.Error(500, "Failed to publish event", err)
+		return response.Error(http.StatusInternalServerError, "Failed to publish event", err)
 	}
 
 	// mark temp user as completed
@@ -134,7 +134,7 @@ func (hs *HTTPServer) SignUpStep2(c *contextmodel.ReqContext) response.Response
 	invitesQuery := tempuser.GetTempUsersQuery{Email: form.Email, Status: tempuser.TmpUserInvitePending}
 	invitesQueryResult, err := hs.tempUserService.GetTempUsersQuery(c.Req.Context(), &invitesQuery)
 	if err != nil {
-		return response.Error(500, "Failed to query database for invites", err)
+		return response.Error(http.StatusInternalServerError, "Failed to query database for invites", err)
 	}
 
 	apiResponse := util.DynMap{"message": "User sign up completed successfully", "code": "redirect-to-landing-page"}
@@ -147,7 +147,7 @@ func (hs *HTTPServer) SignUpStep2(c *contextmodel.ReqContext) response.Response
 
 	err = hs.loginUserWithUser(usr, c)
 	if err != nil {
-		return response.Error(500, "failed to login user", err)
+		return response.Error(http.StatusInternalServerError, "failed to login user", err)
 	}
 
 	metrics.MApiUserSignUpCompleted.Inc()
@@ -161,14 +161,14 @@ func (hs *HTTPServer) verifyUserSignUpEmail(ctx context.Context, email string, c
 	queryResult, err := hs.tempUserService.GetTempUserByCode(ctx, &query)
 	if err != nil {
 		if errors.Is(err, tempuser.ErrTempUserNotFound) {
-			return false, response.Error(404, "Invalid email verification code", nil)
+			return false, response.Error(http.StatusNotFound, "Invalid email verification code", nil)
 		}
-		return false, response.Error(500, "Failed to read temp user", err)
+		return false, response.Error(http.StatusInternalServerError, "Failed to read temp user", err)
 	}
 
 	tempUser := queryResult
 	if tempUser.Email != email {
-		return false, response.Error(404, "Email verification code does not match email", nil)
+		return false, response.Error(http.StatusNotFound, "Email verification code does not match email", nil)
 	}
 
 	return true, nil
