@@ -3,7 +3,7 @@ package v0alpha1
 import (
 	"k8s.io/apimachinery/pkg/runtime"
 
-	common "github.com/grafana/grafana/pkg/apis/common/v0alpha1"
+	common "github.com/grafana/grafana/pkg/apimachinery/apis/common/v0alpha1"
 )
 
 const (
