@@ -3,7 +3,7 @@ package v0alpha1
 import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	common "github.com/grafana/grafana/pkg/apis/common/v0alpha1"
+	common "github.com/grafana/grafana/pkg/apimachinery/apis/common/v0alpha1"
 )
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -39,6 +39,6 @@ type HealthCheckResult struct {
 	// Optional description for the data source
 	Message string `json:"message,omitempty"`
 
-	// Spec depends on the the plugin
+	// Spec depends on the plugin
 	Details *common.Unstructured `json:"details,omitempty"`
 }
